EXPORTS
	?ActivateRfForEmergencyCall@RSsmEmergencyCallRfAdaptation@@QAEXAAVTRequestStatus@@@Z @ 1 NONAME ; void RSsmEmergencyCallRfAdaptation::ActivateRfForEmergencyCall(class TRequestStatus &)
	?Cancel@RSsmEmergencyCallRfAdaptation@@QAEXXZ @ 2 NONAME ; void RSsmEmergencyCallRfAdaptation::Cancel(void)
	?Cancel@RSsmMiscAdaptation@@QAEXXZ @ 3 NONAME ; void RSsmMiscAdaptation::Cancel(void)
	?Cancel@RSsmRtcAdaptation@@QAEXXZ @ 4 NONAME ; void RSsmRtcAdaptation::Cancel(void)
	?Connect@RSsmAdaptationBase@@QAEHH@Z @ 5 NONAME ; int RSsmAdaptationBase::Connect(int)
	?Connect@RSsmAdaptationBase@@QAEHXZ @ 6 NONAME ; int RSsmAdaptationBase::Connect(void)
	?DeactivateRfForEmergencyCall@RSsmEmergencyCallRfAdaptation@@QAEXAAVTRequestStatus@@@Z @ 7 NONAME ; void RSsmEmergencyCallRfAdaptation::DeactivateRfForEmergencyCall(class TRequestStatus &)
	?GetCancel@RSsmSimAdaptation@@QAEXXZ @ 8 NONAME ; void RSsmSimAdaptation::GetCancel(void)
	?GetGlobalStartupMode@RSsmMiscAdaptation@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 9 NONAME ; void RSsmMiscAdaptation::GetGlobalStartupMode(class TDes8 &, class TRequestStatus &)
	?GetLastCoopSysEvent@RSsmStateAdaptation@@QAEXAAVTDes8@@@Z @ 10 NONAME ; void RSsmStateAdaptation::GetLastCoopSysEvent(class TDes8 &)
	?GetLastSimEvent@RSsmSimAdaptation@@QAEXAAVTDes8@@@Z @ 11 NONAME ; void RSsmSimAdaptation::GetLastSimEvent(class TDes8 &)
	?GetSimChanged@RSsmSimAdaptation@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 12 NONAME ABSENT ; void RSsmSimAdaptation::GetSimChanged(class TDes8 &, class TRequestStatus &)
	?SimLanguagesArrayL@RSsmMiscAdaptation@@QAEPAV?$CArrayFix@J@@H@Z @ 13 NONAME ; class CArrayFix<long> * RSsmMiscAdaptation::SimLanguagesArrayL(int)
	?GetSimOwned@RSsmSimAdaptation@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 14 NONAME ; void RSsmSimAdaptation::GetSimOwned(class TDes8 &, class TRequestStatus &)
	?NotifyCancel@RSsmSimAdaptation@@QAEXXZ @ 15 NONAME ; void RSsmSimAdaptation::NotifyCancel(void)
	?NotifyCancel@RSsmStateAdaptation@@QAEXXZ @ 16 NONAME ; void RSsmStateAdaptation::NotifyCancel(void)
	?NotifyCoopSysEvent@RSsmStateAdaptation@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 17 NONAME ; void RSsmStateAdaptation::NotifyCoopSysEvent(class TDes8 &, class TRequestStatus &)
	?NotifySimEvent@RSsmSimAdaptation@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 18 NONAME ; void RSsmSimAdaptation::NotifySimEvent(class TDes8 &, class TRequestStatus &)
	?PrepareSimLanguages@RSsmMiscAdaptation@@QAEXW4TSsmLanguageListPriority@@AAVTDes8@@AAVTRequestStatus@@@Z @ 19 NONAME ; void RSsmMiscAdaptation::PrepareSimLanguages(enum TSsmLanguageListPriority, class TDes8 &, class TRequestStatus &)
	?RequestCancel@RSsmStateAdaptation@@QAEXXZ @ 20 NONAME ; void RSsmStateAdaptation::RequestCancel(void)
	?RequestCoopSysPerformRestartActions@RSsmStateAdaptation@@QAEXHAAVTRequestStatus@@@Z @ 21 NONAME ; void RSsmStateAdaptation::RequestCoopSysPerformRestartActions(int, class TRequestStatus &)
	?RequestCoopSysPerformRfsActions@RSsmStateAdaptation@@QAEXW4TSsmRfsType@@AAVTRequestStatus@@@Z @ 22 NONAME ; void RSsmStateAdaptation::RequestCoopSysPerformRfsActions(enum TSsmRfsType, class TRequestStatus &)
	?RequestCoopSysPerformShutdownActions@RSsmStateAdaptation@@QAEXHAAVTRequestStatus@@@Z @ 23 NONAME ; void RSsmStateAdaptation::RequestCoopSysPerformShutdownActions(int, class TRequestStatus &)
	?RequestCoopSysSelfTest@RSsmStateAdaptation@@QAEXAAVTRequestStatus@@@Z @ 24 NONAME ; void RSsmStateAdaptation::RequestCoopSysSelfTest(class TRequestStatus &)
	?RequestCoopSysStateChange@RSsmStateAdaptation@@QAEXVTSsmState@@AAVTRequestStatus@@@Z @ 25 NONAME ; void RSsmStateAdaptation::RequestCoopSysStateChange(class TSsmState, class TRequestStatus &)
	?SecurityStateChange@RSsmMiscAdaptation@@QAEXHAAVTDes8@@AAVTRequestStatus@@@Z @ 26 NONAME ; void RSsmMiscAdaptation::SecurityStateChange(int, class TDes8 &, class TRequestStatus &)
	?SetWakeupAlarm@RSsmRtcAdaptation@@QAEXAAVTDesC8@@AAVTRequestStatus@@@Z @ 27 NONAME ; void RSsmRtcAdaptation::SetWakeupAlarm(class TDesC8 &, class TRequestStatus &)
	?UnsetWakeupAlarm@RSsmRtcAdaptation@@QAEXAAVTRequestStatus@@@Z @ 28 NONAME ; void RSsmRtcAdaptation::UnsetWakeupAlarm(class TRequestStatus &)
	?ValidateRtc@RSsmRtcAdaptation@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 29 NONAME ; void RSsmRtcAdaptation::ValidateRtc(class TDes8 &, class TRequestStatus &)
	?GetHiddenReset@RSsmMiscAdaptation@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 30 NONAME ; void RSsmMiscAdaptation::GetHiddenReset(class TDes8 &, class TRequestStatus &)
	?SetAsPriorityClient@RSsmEmergencyCallRfAdaptation@@QAEHXZ @ 31 NONAME ; int RSsmEmergencyCallRfAdaptation::SetAsPriorityClient(void)

